@@ -920,7 +920,6 @@ class RemoteJob(object):
         """
         if self._cur_batch_size >= self._batch_size:
             self.submit()
-            self._cur_batch_size = 0
 
     def put_points(self, series_id, points):
         """
@@ -986,10 +985,12 @@ class RemoteJob(object):
 
         #we send the bulk data at once
         if bulk_data:
-            self._conn._post_bulk(bulk_data, self._job_id)
-
-        #also empty the current cache
-        self._values = {}
+            try:
+                self._conn._post_bulk(bulk_data, self._job_id)
+            finally:
+                # flush cache to avoid re-raising the same exceptions
+                self._values = {}
+                self._cur_batch_size = 0
         return True
 
 
